# -*- coding: utf-8 -*-
#
# File: Club.py
#
# Copyright (c) 2007 by Solurity, Inc.
# Generator: ArchGenXML 
#            http://plone.org/products/archgenxml
#
# GNU General Public License (GPL)
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.
#

__author__ = """G. Clifford Williams <gcw@solurity.com>"""
__docformat__ = 'plaintext'

from AccessControl import ClassSecurityInfo
from Products.Archetypes.atapi import *
from Products.ATVocabularyManager.namedvocabulary import NamedVocabulary
from Products.Club.config import *

##code-section module-header #fill in your manual code here
from Products.Archetypes.public import DisplayList
from Products.Archetypes.public import *
from Products.ATContentTypes.content.base import ATCTOrderedFolder, ATCTFolder
from Products.ATContentTypes.content.folder import ATFolderSchema, ATFolder
from Products.CMFCore.utils import getToolByName

from Products.DataGridField import DataGridField, DataGridWidget
from Products.DataGridField.Column import Column
from Products.DataGridField.SelectColumn import SelectColumn
# from Products.DataGridField.RadioColumn import RadioColumn
from Products.ATVocabularyManager.namedvocabulary import NamedVocabulary
##/code-section module-header

schema = Schema((

    StringField(
        name='Address1',
        index="ZCTextIndex:brains",
        widget=StringWidget(
            label="Address",
            label_msgid='Club_label_Address1',
            i18n_domain='Club',
        ),
        required=1,
        searchable=1
    ),

    StringField(
        name='City',
        index="ZCTextIndex:brains",
        widget=StringWidget(
            label='City',
            label_msgid='Club_label_City',
            i18n_domain='Club',
        ),
        required=1,
        searchable=1
    ),

    StringField(
        name='State',
        index="ZCTextIndex:brains",
        widget=SelectionWidget(
            label="State or Province",
            format="select",
            description="Use the one or two letter code for the state or province",
            label_msgid='Club_label_State',
            description_msgid='Club_help_State',
            i18n_domain='Club',
        ),
        vocabulary=NamedVocabulary("""ClubState"""),
        searchable=1,
        required=0
    ),

    StringField(
        name='Country',
        widget=SelectionWidget(
            format="select",
            description="Use the ISO two letter code for the country",
            label='Country',
            label_msgid='Club_label_Country',
            description_msgid='Club_help_Country',
            i18n_domain='Club',
        ),
        required=1,
        vocabulary=NamedVocabulary("""ClubCountry""")
    ),

    StringField(
        name='Web',
        index="ZCTextIndex:brains",
        widget=StringWidget(
            description="example: www.clave.info",
            label='Web',
            label_msgid='Club_label_Web',
            description_msgid='Club_help_Web',
            i18n_domain='Club',
        ),
        required=0,
        searchable=1
    ),

    StringField(
        name='Phone',
        index="ZCTextIndex:brains",
        widget=StringWidget(
            label='Phone',
            label_msgid='Club_label_Phone',
            i18n_domain='Club',
        ),
        required=0,
        searchable=1
    ),

    StringField(
        name='Sponsor',
        index="ZCTextIndex:brains",
        widget=StringWidget(
            label="Sponsored or Promoted by",
            label_msgid='Club_label_Sponsor',
            i18n_domain='Club',
        ),
        required=0,
        searchable=1
    ),

    DataGridField(
        name='Schedule',
        index="ZCTextIndex:brains",
        widget=DataGridWidget(
            columns={
               'Day' : SelectColumn("Day", vocabulary="getClubDaysVocabulary"),
               'From' : SelectColumn("From", vocabulary="getClubTimesVocabulary"),
               'To' : SelectColumn("To",vocabulary="getClubTimesVocabulary"),
               'Description' : Column("Description")
            },
            label='Schedule',
            label_msgid='Club_label_Schedule',
            i18n_domain='Club',
        ),
        columns=("Day", "From", "To","Description")
    ),

    StringField(
        name='Styles',
        index="ZCTextIndex:brains",
        widget=MultiSelectionWidget(
            description="""Styles of music or dance
            Select all that apply""",
            format="checkbox",
            label='Styles',
            label_msgid='Club_label_Styles',
            description_msgid='Club_help_Styles',
            i18n_domain='Club',
        ),
        vocabulary=NamedVocabulary("""ClubStyles"""),
        searchable=1
    ),

),
)

##code-section after-local-schema #fill in your manual code here
##/code-section after-local-schema

Club_schema = BaseSchema.copy() + \
    schema.copy()

##code-section after-schema #fill in your manual code here
Club_schema = ATFolderSchema.copy() + schema.copy()

##/code-section after-schema

class Club(ATFolder):
    """
    """
    security = ClassSecurityInfo()
    __implements__ = (getattr(ATFolder,'__implements__',()),)

    # This name appears in the 'add' box
    archetype_name = 'Club'

    meta_type = 'Club'
    portal_type = 'Club'
    allowed_content_types = ['Image', 'Event', 'ClubReview']
    filter_content_types = 1
    global_allow = 1
    content_icon = 'club-icon.png'
    immediate_view = 'club_view'
    default_view = 'club_view'
    suppl_views = ()
    typeDescription = "Club"
    typeDescMsgId = 'description_edit_club'
    allow_discussion = 1

    _at_rename_after_creation = False

    schema = Club_schema

    ##code-section class-header #fill in your manual code here
    #These methods are used by DatagridFields to populate their
    #selectcolumns.
    def getClubTimesVocabulary(self):
        clubtimesduf = NamedVocabulary("""ClubTimes""").getDisplayList(self)
        print "got:" + str(clubtimesduf)
        return clubtimesduf

    def getClubLessonVocabulary(self):
        clublessonsduf = NamedVocabulary("""ClubLessons""").getDisplayList(self)
        print "got:" + str(clublessonsduf)
        return clublessonsduf

    def getClubDaysVocabulary(self):
        clubdaysduf = NamedVocabulary("""ClubDays""").getDisplayList(self)
        print "got:" + str(clubdaysduf)
        return clubdaysduf



    ##/code-section class-header

    # Methods

    # Manually created methods

    def getClubDaysVocabulary(self):
        clubdaysduf = NamedVocabulary("""ClubDays""").getDisplayList(self)
        print "got:" + str(clubdaysduf)
        return clubdaysduf

    def getClubTimesVocabulary(self):
        clubtimesduf = NamedVocabulary("""ClubTimes""").getDisplayList(self)
        print "got:" + str(clubtimesduf)
        return clubtimesduf

    def getClubLessonVocabulary(self):
        clublessonsduf = NamedVocabulary("""ClubLessons""").getDisplayList(self)
        print "got:" + str(clublessonsduf)
        return clublessonsduf



registerType(Club, PROJECTNAME)
# end of class Club

##code-section module-footer #fill in your manual code here
##/code-section module-footer



